==> Skellett%201.7.7b.src.zip: Skellett-Legacy-1.7.7b/SkellettGit/src/com/gmail/thelimeglass/Expressions/ExprLlamaInventoryDecor.java <==
package com.gmail.thelimeglass.Expressions;

import javax.annotation.Nullable;

import org.bukkit.event.Event;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.LlamaInventory;

import com.gmail.thelimeglass.Utils.Config;
import com.gmail.thelimeglass.Utils.PropertyType;
import com.gmail.thelimeglass.Utils.Syntax;
import com.gmail.thelimeglass.Utils.Version;

import ch.njol.skript.classes.Changer;
import ch.njol.skript.classes.Changer.ChangeMode;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.SkriptParser.ParseResult;
import ch.njol.skript.lang.util.SimpleExpression;
import ch.njol.util.Kleenean;
import ch.njol.util.coll.CollectionUtils;

@Syntax({"[Llama] decor (of|in) [inventory] [of] [Llama] %llamainventory%", "[Llama] %llamainventory%'s [inventory] decor"})
@Config("LlamaInventoryDecor")
@PropertyType("COMBINED")
@Version("1.11")
public class ExprLlamaInventoryDecor extends SimpleExpression<ItemStack>{
	
	private Expression<LlamaInventory> inventory;
	@Override
	public Class<? extends ItemStack> getReturnType() {
		return ItemStack.class;
	}
	@Override
	public boolean isSingle() {
		return true;
	}
	@SuppressWarnings("unchecked")
	@Override
	public boolean init(Expression<?>[] e, int matchedPattern, Kleenean isDelayed, ParseResult parser) {
		inventory = (Expression<LlamaInventory>) e[0];
		return true;
	}
	@Override
	public String toString(@Nullable Event e, boolean arg1) {
		return "[Llama] decor (of|in) [inventory] [of] [Llama] %llamainventory%";
	}
	@Override
	@Nullable
	protected ItemStack[] get(Event e) {
		return new ItemStack[]{inventory.getSingle(e).getDecor()};
	}
	@Override
	public void change(Event e, Object[] delta, Changer.ChangeMode mode){
		if (mode == ChangeMode.SET) {
			inventory.getSingle(e).setDecor((ItemStack)delta[0]);
		}
	}
	@SuppressWarnings("unchecked")
	@Override
	public Class<?>[] acceptChange(final Changer.ChangeMode mode) {
		if (mode == ChangeMode.SET) {
			return CollectionUtils.array(ItemStack.class);
		}
		return null;
	}
}

==> Skellett%201.9.4.src.zip: Skellett-Legacy-1.9.4/SkellettGit/src/com/gmail/thelimeglass/Expressions/ExprLlamaInventoryDecor.java <==
package com.gmail.thelimeglass.Expressions;

import javax.annotation.Nullable;

import org.bukkit.event.Event;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.LlamaInventory;

import com.gmail.thelimeglass.Utils.Config;
import com.gmail.thelimeglass.Utils.PropertyType;
import com.gmail.thelimeglass.Utils.Syntax;
import com.gmail.thelimeglass.Utils.Version;

import ch.njol.skript.classes.Changer;
import ch.njol.skript.classes.Changer.ChangeMode;
import ch.njol.skript.lang.Expression;
import ch.njol.skript.lang.ExpressionType;
import ch.njol.skript.lang.SkriptParser.ParseResult;
import ch.njol.skript.lang.util.SimpleExpression;
import ch.njol.util.Kleenean;
import ch.njol.util.coll.CollectionUtils;

@Syntax({"[Llama] decor (of|in) [inventory] [of] [Llama] %llamainventory%", "[Llama] %llamainventory%'s [inventory] decor"})
@Config("LlamaInventoryDecor")
@PropertyType(ExpressionType.COMBINED)
@Version("1.11")
public class ExprLlamaInventoryDecor extends SimpleExpression<ItemStack>{
	
	private Expression<LlamaInventory> inventory;
	@Override
	public Class<? extends ItemStack> getReturnType() {
		return ItemStack.class;
	}
	@Override
	public boolean isSingle() {
		return true;
	}
	@SuppressWarnings("unchecked")
	@Override
	public boolean init(Expression<?>[] e, int matchedPattern, Kleenean isDelayed, ParseResult parser) {
		inventory = (Expression<LlamaInventory>) e[0];
		return true;
	}
	@Override
	public String toString(@Nullable Event e, boolean arg1) {
		return "[Llama] decor (of|in) [inventory] [of] [Llama] %llamainventory%";
	}
	@Override
	@Nullable
	protected ItemStack[] get(Event e) {
		return new ItemStack[]{inventory.getSingle(e).getDecor()};
	}
	@Override
	public void change(Event e, Object[] delta, Changer.ChangeMode mode){
		if (mode == ChangeMode.SET) {
			inventory.getSingle(e).setDecor((ItemStack)delta[0]);
		}
	}
	@Override
	public Class<?>[] acceptChange(final Changer.ChangeMode mode) {
		if (mode == ChangeMode.SET) {
			return CollectionUtils.array(ItemStack.class);
		}
		return null;
	}
}
